%This matlab file reads the data generated by the Analysis Sequences
%in the DemoModels and plots the comparisons between Coustyx results 
%and Analytical results.

%********************************************************************
% Room acoustics in the presence of a point source - Demo model
%********************************************************************

%********************************************************************
% Run the following Analysis Sequences in the Demo Model,
% before running this matlab script. 
%  RunValidation - FMM
%********************************************************************
resultsFMM = load('validation_results_fmm.txt');

% Each *.txt results file has 5 columns, where
%  results(:,1) = frequency of analysis in Hz
%  results(:,2) = Real part of coustyx field point pressure
%  results(:,3) = Imaginary part of coustyx field point pressure
%  results(:,4) = Real part of analytical pressure
%  results(:,5) = Imaginary part of analytical pressure


%Acoustic medium properties:
%  rho_o = medium density of air = 1.21 
%  c = speed of sound = 343 
%  b0 = monopole volume velocity = 1
rho_o = 1.21;
c = 343;
bo = 1;
Freq = resultsFMM(:,1);
k = 2*pi*Freq/c;
P0 = abs(i*k*rho_o*c*bo);
%********************************************************************
%Plot FMM and Analytical results
%********************************************************************
figure;
plot(resultsFMM(:,1),abs(resultsFMM(:,2)+i*resultsFMM(:,3))./P0,'r-',...
    resultsFMM(:,1),abs(resultsFMM(:,4)+i*resultsFMM(:,5))./P0,'b.');
legend('Coustyx-FMM','Analytical');
title('Field point pressures per unit monopole strength - amplitude');
xlabel('Frequency, Hz');
ylabel('p/P0');

figure;
plot(resultsFMM(:,1),angle(resultsFMM(:,2)+i*resultsFMM(:,3))*180/pi,'r-',...
    resultsFMM(:,1),angle(resultsFMM(:,4)+i*resultsFMM(:,5))*180/pi,'b.');
legend('Coustyx-FMM','Analytical');
title('Field point pressures per unit monopole strength - Phase angle');
xlabel('Frequency, Hz');
ylabel('Phase, deg');


matFMM = [resultsFMM(:,1) (abs(resultsFMM(:,2)+i*resultsFMM(:,3))./P0) (abs(resultsFMM(:,4)+i*resultsFMM(:,5))./P0)];
%save results_abs_fmm.txt matFMM -ASCII



